@@ -1,3 +1,22 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
   	/* ------------------------------------------------------------
  	*       Clear_display takes  care of status lines  and
  	*       backgrounds (general repaint of the screen)
@@ -7,6 +26,7 @@
 
 void clear_display(void)
 {
+extern int use_rxvt;
 extern char speedstr[];
 extern int speed;
 extern int cury, curx;
@@ -34,12 +54,9 @@ extern int arrldx_usa;
 extern char comment[];
 extern char hiscall[];
 extern int searchflg;
-//extern char lastwwv[];
-//extern int cluster;
 extern int m;
 extern struct tm *time_ptr;
 
-
 char time_buf[80];
 char speedbuf[3] = "  ";
 char month[3] = "01";
@@ -54,7 +71,8 @@ mvprintw(0,0,"                             ");
 mvprintw(0,0,"  %s  S=%s D=%i ",mode, speedbuf, cqdelay);
 mvprintw(0,   21, headerline);
 
-attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
+if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
+else   attron(COLOR_PAIR(COLOR_WHITE |  A_STANDOUT));
 	
 	mvaddstr(1,  0, terminal1);
 	mvaddstr(2,  0, terminal2);
@@ -64,7 +82,10 @@ attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
 	mvprintw(6, 0,  "");
 mvaddstr(6,0,  "");
 hline(ACS_HLINE, 80);
-attron(COLOR_PAIR(COLOR_WHITE) | A_BOLD | A_STANDOUT);
+
+if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_WHITE) | A_BOLD | A_STANDOUT);
+else  attron(COLOR_PAIR(COLOR_WHITE)  | A_STANDOUT);
+
 mvaddstr(7, 0, logline0);
 mvaddstr(8, 0, logline1);
 mvaddstr(9, 0, logline2);
@@ -108,26 +129,32 @@ mvaddstr(12, 49, my_rst);
 
 
 if (cqww==1) {
-    attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+    	if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+		else  attron(COLOR_PAIR(NORMCOLOR) );
 	mvaddstr(12,54,comment);
 	}
 	
 if (arrldx_usa ==1) {
-    attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+    	if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+		else    attron(COLOR_PAIR(NORMCOLOR) );
 	mvaddstr(12,54,comment);
 	}
 
 if (searchflg == SEARCHWINDOW)
 	searchlog(hiscall);
 
-attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+else   attron(COLOR_PAIR(NORMCOLOR)  );
+
  mvaddstr(12, 29, hiscall);
 
 
 	attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
 	mvprintw(24,0,  backgrnd_str);
-		
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
+
+	if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
+	else   attron(COLOR_PAIR(NORMCOLOR) );
+
 	mvprintw(cury,  curx, "");
 	refresh();
 }
