@@ -1,7 +1,27 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 #include "freq_display.h"
 
 int freq_display (void) {
 
+extern int use_rxvt;
 extern float freq;
 extern int trxmode;
 
@@ -256,8 +276,13 @@ return(0);
 
 int print_space(int y, int x){
 
+extern int use_rxvt;
+
 attroff(A_STANDOUT);
-attron(COLOR_PAIR(COLOR_WHITE) |  A_BOLD );
+
+if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_WHITE) |  A_BOLD );
+else  attron(COLOR_PAIR(COLOR_WHITE) );
+
 mvprintw(y,x,"                                   ");
 
 
