@@ -1,3 +1,22 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
   	/* ------------------------------------------------------------
  	*        Get messages  from  -paras file
  	*        and  gets  the last  5 qso records for  display
@@ -22,7 +41,6 @@ extern char para_word[];
 extern int shortqsonr;
 extern int cluster;
 extern int searchflg;
-extern int contest;
 extern int demode;
 extern int announcefilter;
 extern int showscore_flag;
@@ -41,6 +59,7 @@ extern char logline4[];
 extern char backgrnd_str[];
 extern char C_QTH_Lat[];
 extern char C_QTH_Long[];
+extern int emptydir;
 
 extern struct tm *time_ptr;
 
@@ -90,7 +109,7 @@ printw(mycqzone);
 printw("     My Continent = ");
 printw(mycontinent);
 
-printw("\n\n     Messages: \n\n");
+printw("\n\n");
 refresh();
 
 for ( i = 0; i <= 13; i++){
@@ -102,10 +121,7 @@ for ( i = 0; i <= 13; i++){
 
 	
 	strcpy (message[i], inputbuffer);
-	if  (i <= 11){
-		printw  ("        ");
-		printw (message[i]);
-	}
+
 }
 strcpy(sp_return, message[12]);
 strcpy(cq_return, message[13]);
@@ -169,12 +185,12 @@ if (para_word[3] == 'D')
 	demode = 1;
 else
 	demode =  0;
-	
+/*
 if (para_word[4]  == 'C')
 	contest = 1;
 else
 	contest = 0;
-	
+*/	
 if (para_word[5] == 'F')
 	announcefilter = 1;
 else
@@ -184,7 +200,7 @@ if (para_word[6] ==  'S')
 	showscore_flag = 1;
 else
 	showscore_flag = 0;
-	
+/*
 if ((para_word[7] >= 49) && (para_word[7] < 68))
 	speed  = (para_word[7] - 48);
 
@@ -195,7 +211,7 @@ if (para_word[9] == 'C')
 	trxmode = CWMODE;
 else
 	trxmode = SSBMODE;
-	
+*/	
 fclose(fp);
 
 checklogfile();
@@ -236,7 +252,7 @@ if (strlen(logline[0]) >= 75)
 	strncpy(logline0,  logline[0], 80);
 else
 	strcpy(logline0, backgrnd_str);
-	
+
 if (strlen(logline[1]) >= 75)
 	strncpy(logline1,  logline[1], 80);
 else
@@ -257,20 +273,32 @@ if (strlen(logline[4]) >= 75)
 else
 	strcpy(logline4, backgrnd_str);	
 	
+refresh();
 
 fclose(fp);
 
-get_time();
-strftime(time_buf, 60, "\n     System Time is:  %d-%b-%Y %H:%M \n",  time_ptr);
+if (emptydir == 1) {
 
-printw(time_buf);
-refresh();
+	printw ("\n");
+	printw ("           TTTTT  L      FFFFF\n");
+	printw ("             T    L      F    \n");
+	printw ("             T    L      FFFFF\n");
+	printw ("             T    L      F    \n");
+	printw ("             T    LLLLL  F    \n");
+	printw ("\n\n This program is copyright 2001, 2002, 2003 by Rein Couperus, PA0RCT\n\n");
+	printw (" It is free software; you can redistribute it and/or modify");
+	printw (" it under the terms of the GNU General Public License as published by");
+	printw (" the Free Software Foundation; either version 2 of the License, or");
+	printw (" (at your option) any later version.\n\n");
+	printw (" This program is distributed in the hope that it will be useful,");
+	printw (" but WITHOUT ANY WARRANTY; without even the implied warranty of");
+	printw (" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the");
+	printw (" GNU General Public License for more details.\n");
 
+	refresh();
 
-box(stdscr, ACS_VLINE, ACS_HLINE);
-refresh();
-
-sleep(1);
+	sleep(5);
+}
 
 return(0);
 
