@@ -1,3 +1,22 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 	/* ------------------------------------------------------------
  	*   write summary  file
  	*
@@ -15,6 +34,8 @@
  	extern int arrldx_usa;
  	extern int totalmults;
  	extern char exchange[];
+	extern int multcount;
+	extern int arrlss;
  	
  	int getsummary(void)
  	{
@@ -30,18 +51,17 @@
 	}
  	
 	fputs("START-OF-LOG: 2.0\n", fp);
-	
-	if (arrldx_usa == 1) {	
+
 		attron(A_STANDOUT);
         mvprintw(15,1, "                                                                                    ");
-        nicebox(14,0, 1, 78, "Your exchange (State, e.g. NY): ");
+        nicebox(14,0, 1, 78, "Your exchange (e.g. State, province, age etc... (# if serial number)): ");
         attron(A_STANDOUT);
         mvprintw(15,1,"");
 		echo();
 		getnstr(buffer, 78);
 		noecho();
 		strncpy(exchange, buffer, 3);
-	}
+		
 		attron(A_STANDOUT);
         mvprintw(15,1, "                                                                                    ");
         nicebox(14,0, 1, 78, "ARRL-SECTION:");
@@ -114,14 +134,15 @@
 		noecho();
 		strcat(buffer,  "\n");
 	fputs(buffer, fp);
-	
+
 	if (wpx == 1)
 		sprintf(buffer, "%d\n",total  * (nr_of_px ));
 	if (cqww == 1)
 	    sprintf(buffer, "%d\n",total  * totalmults);
 	if (arrldx_usa == 1)
 	    sprintf(buffer, "%d\n",total  * totalmults);
-	
+	if (arrlss == 1)
+		sprintf(buffer, "%d\n", multcount * total);
 	fputs("CLAIMED-SCORE: ", fp);
 	fputs( buffer, fp);
 	fputs("CLUB: ", fp);
@@ -148,7 +169,7 @@
 		noecho();
 		strcat(buffer, "\n");
 	fputs(buffer, fp);
-	fputs("CREATED-BY: tlf-0.5.2\n", fp);
+	fputs("CREATED-BY: tlf-0.8.20\n", fp);
         attron(A_STANDOUT);
         mvprintw(15,1, "                                                                                    ");
         nicebox(14,0, 1, 78, "Name: ");
