@@ -1,9 +1,29 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 /*------------------------------------------------------------------------
 
     CW keyboard routine
 
 ------------------------------------------------------------------------*/
 #include "keyer.h"
+#include "netkeyer.h"
 
 int keyer(void)
 {
@@ -19,16 +39,12 @@ extern char message[15][80];
 extern char wkeyerbuffer[];
 extern int data_ready;
 extern int keyerport;
+extern int weight;
 
-int x = 0, i = 0;
-char comstr[80];
-char comstr2[2];
-char comstr3[] = " > /dev/cwkeyer";
-
-comstr2[0] = 34;
-comstr2[1] = '\0';
-
-	strcpy(comstr3, " >> txfile");
+int x = 0, i = 0, j=0;
+char nkbuffer[2];
+char keyerstring[30]="                              ";
+char weightbuf[15];
 
 strcpy (mode,  "Keyboard");
 clear_display();
@@ -45,11 +61,11 @@ while (1)
 		 	x = 32;
 		}
 		
-		if  (x  == 27){		
+		if  (x  == 27 || x == 11 || x == 235){		
 		    stoptx();
 			break;
-			}
-		
+		}
+
 		if  (x  >= 32 && x <=  125 ){
 			addch(x);
 			refresh();
@@ -94,55 +110,62 @@ while (1)
 			}
 			else
 			{
-				if ((x == 40) || (x == 43) || (x == 45) ||(x == 60 ) || ( x == 61) || ( x == 62) ||( x == 63) ||( x == 33) || ( x == 38 )){
-					buffer[bufloc] = x;
-					bufloc++;
-					buffer[bufloc] = '\0';
-					x = 32;
-				}	
-				
-				if (x > 32)
+				if (keyerport != NET_KEYER) {
+
+					if ((x == 40) || (x == 43) || (x == 45) ||(x == 60 ) || ( x == 61) || ( x == 62) ||( x == 63) ||( x == 33) || ( x == 38 )){
+						buffer[bufloc] = x;
+						bufloc++;
+						buffer[bufloc] = '\0';
+						x = 32;
+					}
+				}
+
+				if (x > 31)
 				{
-				buffer[bufloc] = x;
-				bufloc++;
-				buffer[bufloc] = '\0';
+					if (keyerport != NET_KEYER) {
+						buffer[bufloc] = x;
+						bufloc++;
+						buffer[bufloc] = '\0';
+					}  else {
+						nkbuffer[0]= x;                             // 1 char at the time !
+						nkbuffer[1]='\0';
+						netkeyer(K_MESSAGE, nkbuffer);
+						nkbuffer[0]='\0';
+						for (j = 0; j <29 ; j++)  {
+							keyerstring[j] = keyerstring[j+1];
+						}
+						keyerstring[28]= x;
+						keyerstring[29]='\0';
+
+						attron(COLOR_PAIR(7)  |  A_STANDOUT);
+						mvprintw(5,0, "%s", keyerstring);
+						refresh();
+					}
 				}
 				else
 				{
-				comstr[0] = '\0';
-				strcat(comstr, "echo ");
-				strcat(comstr, comstr2);				
-				strcat(comstr, buffer);
-				strcat(comstr, comstr2);
-				strncat(comstr, comstr3, 15);
-				getyx(stdscr, cury,  curx);
-				attron(COLOR_PAIR(COLOR_MAGENTA) | A_STANDOUT );
-				mvaddstr(0, 0 ,"  ");
-				attron(COLOR_PAIR(COLOR_WHITE));
-				mvaddstr(cury,curx,"");
-				refresh();
-				
-                if (data_ready != 1) {
+
+				if (data_ready != 1) {
 						strcat(wkeyerbuffer, buffer);
 						data_ready = 1;
 				}else
 						buffer[0] = '\0';
-				
+
 				getyx(stdscr, cury,  curx);
 				attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT );
 				mvaddstr(0,0,"  ");
 				attron(COLOR_PAIR(7));
 				mvaddstr(cury,curx,"");
 				refresh();
-			
-					
+
+
 					strcat(termbuf, buffer);
 					strcat(termbuf, " ");
 					mvprintw(5,0, termbuf);
 					refresh();
 					
 				if ((strlen(buffer) + strlen(termbuf) > 39 )  || x == '=')
-					{			
+					{
 								 i  =  0;
 			 mvprintw(5,0, "                         ");
 			 mvprintw(5,0,"");
@@ -170,6 +193,7 @@ while (1)
 					return(2);
 				}
 				case 27:
+				case 11:
 				{
 					stoptx();
 					bufloc = 0;
@@ -178,6 +202,19 @@ while (1)
     				clear_display();
 					return(2);
 				}
+				case 247:						// Alt-w, set weight
+				{
+					mvprintw(1,0, "Weight=   ");
+					mvprintw(1,7, "");
+					refresh();
+					echo();
+ 					getnstr(weightbuf,  2);
+ 					noecho();
+
+					weight = atoi(weightbuf);
+					netkeyer(K_WEIGHT, weightbuf);
+					break;
+				}
 				case 152:
 				{
 					keyspeed = speedup();
@@ -286,9 +323,10 @@ while (1)
 					break;
 				}
 				
-				case 142: 						       /* CTRL  O */		
+				case 142 ... 150: 						       /* CTRL  O */
+
 				{
-					message_change();
+					message_change(x);
 
 					break;
 						
