@@ -1,9 +1,27 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
   	/* ------------------------------------------------------------
  	*        Makelogline takes care of formatting the log
  	*                       items
  	*--------------------------------------------------------------*/
 
-#include "makelogline.h"
+#include "makelogline.h"                                                      
 
 int makelogline(void)
 {
@@ -25,7 +43,6 @@ extern int cqww;
 extern int pacc_pa_flg;
 extern int universal;
 extern int country_mult;
-extern int other_flg;
 extern int shownewmult;
 extern char mults[MAX_MULTS][12];
 extern int addcallarea;
@@ -35,21 +52,41 @@ extern int dxped;
 extern int contest;
 extern int addcty;
 extern int addzone;
+extern int wysiwyg_multi;
+extern int dx_arrlsections;
 extern char pointstring[];
 extern char datalines[MAX_DATALINES][81];
 extern struct tm *time_ptr;
-extern int sprint;
 extern int one_point;
+extern int two_point;
 extern int three_point;
+extern int lan_active;
+extern int exchange_serial;
+extern char lastqsonr[];
+extern int arrlss;
+extern char ssexchange[];
+extern char section[];
+extern char zone_export[];
+extern char zone_fix[];
+extern int universal;
+extern int serial_section_mult;
+extern int sectn_mult;
+extern int countrynr;
+extern int w_cty;
+extern int ve_cty;
 
 
 static char time_buf[80];
 char fillspaces[50] = "                              ";
+int points=0;
+
 
 logline4[0] = '\0' ;
 qsonr_to_str();
 get_time();
+
 strftime(time_buf, 60, " %d-%b-%y %H:%M ",  time_ptr);
+
 strcat (logline4, band[bandinx]);
 
 if (trxmode == CWMODE)
@@ -60,7 +97,15 @@ else
 	strcat (logline4, "DIG");
 
 strcat (logline4, time_buf);
-strcat (logline4, qsonrstr) ;
+
+if ((lan_active ==1) && (exchange_serial == 1)) {
+	strcat(logline4, lastqsonr);
+	lastqsonr[0]='\0';
+	}
+else
+	strcat (logline4, qsonrstr) ;
+
+
 strcat (logline4, "  ");
 strcat (logline4, hiscall);        		/*  29 */
 lastcall[0] = '\0';                     /* remember  for edit  */
@@ -75,7 +120,7 @@ else {
     his_rst[2] = ' ';
     my_rst[2] = ' ';
 }
-	
+
 strcat (logline4, his_rst);     /* 54 */
 strcat (logline4, "  ");
 strcat (logline4, my_rst);
@@ -84,7 +129,34 @@ strcat (logline4, "  ");
 his_rst[1] = '9';               /* restore RST to 599 */
 my_rst[1] = '9';
 
-strcat(logline4, comment);
+if (arrlss == 1) {         // ----------------------------arrlss----------------
+
+	strcat(logline4, ssexchange);
+	section[0]='\0';
+
+} else if (serial_section_mult == 1) {          //-------------------------serial_section---------------
+
+	sprintf(logline4+54, "%4d %s", atoi(ssexchange), section);
+	section[0]='\0';
+
+} else if (sectn_mult == 1) {          //-------------------------section only---------------
+
+	sprintf(logline4+54, "%s", section);
+	section[0]='\0';
+
+
+} else if (cqww == 1) {          //-------------------------cqww----------------
+/*
+	if (strlen(zone_fix) > 1) {
+		strcat (logline4, zone_fix);
+	} else
+		strcat (logline4, zone_export);
+*/
+ 	strcat(logline4, comment);
+ } else {
+ 	strcat(logline4, comment);
+}                                   //----------------------end cqww ---------------
+
 lastcomment[0] = '\0';
 strcat(lastcomment, comment);           /* remember  for edit  */
 
@@ -93,18 +165,19 @@ strncat (logline4, fillspaces, (20));
 if (contest == 1)
 	logline4[68]='\0';
 
-/* Include new mults in log line */
+/* Include new pfx in log line */
 
 if ((add_pfx()  ==  0) && (wpx == 1)){                    /* wpx */
 	strcat(logline4, pxstr);
 	strncat (logline4, fillspaces, (5 - strlen(pxstr)));
 } else strncat (logline4, fillspaces, 5);
 
-if (cqww == 1){                                    /* cqww */
+
+if (cqww == 1){                                    /* ------------cqww ---------------------*/
      logline4[68]='\0';
 
      if (addcty != 0){
-     	strncat (logline4, datalines[addcty]+ 69, 3);
+     	strncat (logline4, datalines[addcty]+ 69, 4);
      	if (logline4[69] == ':'){
      		logline4[69] = '\0';
      		strncat (logline4, fillspaces, 2);
@@ -113,17 +186,38 @@ if (cqww == 1){                                    /* cqww */
      		logline4[70] = '\0';
      		strncat (logline4, fillspaces, 1);
      	}
-    	strcat (logline4, " ");
+     	if (logline4[71] == ':'){
+     		logline4[71] = '\0';
+     	}
+
+	strcat (logline4, " ");
+	logline4[72]='\0';
      	addcty = 0 ;
      } else strcat (logline4, "    ");
 
      if (addzone != 0){
-     	 	strncat (logline4, comment, 2);
-     	 	strcat(logline4, "   ");
-     	 	addzone = 0;
-     	}else
+/*
+	if (strlen(zone_fix) > 1) {
+		strncat (logline4, zone_fix, 2);
+	} else
+		strncat (logline4, zone_export, 2);
+*/
+	if (strlen(comment) < 2){
+		strcat (logline4, "0");
+		strncat (logline4, comment, 1);
+	}else
+		strncat (logline4, comment, 2);
+
+	strcat(logline4, "   ");
+     	addzone = 0;
+    }else {
      		strcat (logline4, "     ");
 
+	zone_fix[0]='\0';
+
+   }
+			//----------------------------------end cqww-----------------
+
 } else if (arrldx_usa == 1){
       logline4[68]='\0';
       if (addcty != 0){
@@ -138,20 +232,56 @@ if (cqww == 1){                                    /* cqww */
      	}
     	strcat (logline4, " ");
      	addcty = 0 ;
-     	
+
 
      	strcat (logline4, "     ");
 
+      } else
+     		strncat  (logline4,  fillspaces, 9);
+
+ } else if ((dx_arrlsections == 1) && (countrynr != w_cty) && (countrynr != ve_cty)){
+      logline4[68]='\0';
+      if (addcty != 0){
+     	strncat (logline4, datalines[addcty]+ 69, 3);
+     	if (logline4[69] == ':'){
+     		logline4[69] = '\0';
+     		strncat (logline4, fillspaces, 2);
+     	}
+     	if (logline4[70] == ':'){
+     		logline4[70] = '\0';
+     		strncat (logline4, fillspaces, 1);
+     	}
+    	strcat (logline4, " ");
+     	addcty = 0 ;
+
+
+     	strcat (logline4, "     ");
+
+      } else
+     		strncat  (logline4,  fillspaces, 9);
+
+} else if ((wysiwyg_multi == 1) || (serial_section_mult == 1) || (sectn_mult == 1) ){
+       logline4[68]='\0';
+
+	  if (shownewmult >= 0){
+
+     	strcat (logline4, mults[shownewmult]);
+
+    	strncat (logline4, "              |", 77-strlen(logline4));
+     	shownewmult = -1 ;
+
      } else
      	strncat  (logline4,  fillspaces, 9);
-
-} else if (other_flg == 1){
+} else if ((dx_arrlsections == 1) && ((countrynr == w_cty) || (countrynr == ve_cty)) ){
        logline4[68]='\0';
-      if (shownewmult >= 0){
- 	
+
+
+	  if (shownewmult >= 0){
+
      	strcat (logline4, mults[shownewmult]);
-     	
-    	strncat (logline4, "               ", 77-strlen(logline4));
+
+
+    	strncat (logline4, "              |", 77-strlen(logline4));
      	shownewmult = -1 ;
 
      } else
@@ -191,8 +321,11 @@ if (cqww == 1){                                    /* cqww */
 
 
      	strcat (logline4, "    ");
-     }
-} else if ((universal ==1) && (country_mult ==1)){
+      } else
+
+	strncat  (logline4,  fillspaces, 9);
+
+} else if ((universal ==1) &&( (country_mult ==1) || (dx_arrlsections == 1))){
 
       logline4[68]='\0';
 
@@ -220,7 +353,7 @@ if (cqww == 1){                                    /* cqww */
         strncat  (logline4,  fillspaces, 4);
 } else if (arrl_fd == 1){
         strncat  (logline4,  fillspaces, 4);
-} else if ((one_point == 1) || (three_point == 1)){
+} else if ((one_point == 1) || (two_point == 1) || (three_point == 1)){
         strncat  (logline4,  fillspaces, 4);
 }else  {
 	 strncat  (logline4,  fillspaces, 9);
@@ -229,21 +362,15 @@ if (cqww == 1){                                    /* cqww */
 
 	score();		/* update qso's per band */
 
- /* include points in log line */
-if (one_point == 1){
-	pointstring[0] = '1';
-	pointstring[1] = '\0';
-}
-
-if (three_point == 1){
-	pointstring[0] = '3';
-	pointstring[1] = '\0';
-}
-
 if (contest == 1){
-
 	if (dxped != 1){                             /* no points for dxpedition */
-		strcat (logline4,  pointstring);
+		if (pointstring[0] > 57) {
+			points = pointstring[0]-48;
+			sprintf(logline4+76, "%d", points);
+		}else {
+			logline4[77] = '\0';
+			strcat (logline4,  pointstring);
+		}
 	}else{
 		pointstring[0] = ' ';
 		pointstring[1] = '\0';
