@@ -1,3 +1,21 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
  	/* ------------------------------------------------------------
  	*
  	*              Make info string for lower status line
@@ -7,7 +25,8 @@
  	
  	int showinfo(int x){
  	
- 	extern char datalines[MAX_DATALINES][81];
+	extern int use_rxvt;
+	extern char datalines[MAX_DATALINES][81];
 	extern char cqzone[];
 	extern char ituzone[];
 	extern int cury, curx;
@@ -15,6 +34,8 @@
 	extern char C_DEST_Long[];
 	extern double bearing;
 	extern double range;
+	extern int timeoffset;
+	extern int timecorr;
  	
  	char bufstr[81];
  	char pxstr[6];
@@ -73,8 +94,9 @@
  	strncpy (timediffstr, datalines[x] +  60, 6);  /* GMT difference */
  	timediffstr[6] = '\0';
  	d = atof(timediffstr);
- 	now = (time(0) + (-1 * d * 3600));
- 	ptr1 =  localtime (&now);
+
+	now = (time(0) + ((timeoffset- d)* 3600) + timecorr);
+ 	ptr1 =  gmtime (&now);
  	strftime(timebuff, 80,  "%H:%M",  ptr1);
  	
 	
@@ -105,7 +127,9 @@
 		
  		mvprintw(24, 66, "DX time: %s", timebuff);
  	}
-		attron(COLOR_PAIR(NORMCOLOR) | A_BOLD );
+		if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD );
+		else attron(COLOR_PAIR(NORMCOLOR) );
+
 		mvprintw(cury, curx,  "");
 
 	return(0);
