@@ -1,3 +1,21 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
  	/* ------------------------------------------------------------
  	*
  	*              Update time
@@ -19,9 +37,9 @@ extern char logline4[];
 extern char qsonrstr[];
 extern int oldtens;
 extern int bandinx;
-// extern int multi;
 extern int this_second;
- 	
+extern long system_secs;
+
 char time_buf[20];
 int tens  = 1;
 int j;
@@ -29,32 +47,30 @@ static int s;
 static int m;
 
           	usleep(1000);
-          	
+
+         	
           	get_time();
 			strftime(time_buf, 10, "%H:%M:%S",  time_ptr);
 			tens = time_buf[7];        /* seconds */
 			this_second = tens;
+			system_secs= time_buf[3]*10*60 + time_buf[4]  * 60 + time_buf[6] * 10 + time_buf[7]  ;
 			time_buf[5] = '\0';
-						
+
 			if (tens != oldtens ){    /*  seconds */
 				oldtens  = tens;
 				
-    			scroll_log();      /* get logfile/qso nr info */
-				
 
-				if (s >= 2) {
+				if (s >= 0) {
 					
-					if ((time_buf[6] == '1') && (m >= 5)) {   /* 10 seconds */
+					if ((time_buf[6] == '1') && (m >= 30)) {
 						
-						system("egrep -i \"WCY|WWV\" clfile | tail -n1 > wwvfile");
-					
 					    m = 0;
 					    getwwv();
 						
 					} else {
 						m++;
 					}
-					
+
 					clusterinfo(time_buf);  /* update cluster info (2 seconds)*/
 
                     attron(COLOR_PAIR(7) | A_STANDOUT);
